@@ -304,8 +304,8 @@ struct try_s_ {
 #   define try_stack_ ((try_t_ *)pthread_getspecific(try_key_))
 #   define try_stack_set_(next) \
         do { \
-            int try_ret_ = pthread_setspecific(try_key_, next); \
-            assert(try_ret_ == 0 && "try: pthread_setspecific() failed"); \
+            assert(pthread_setspecific(try_key_, next) == 0 && \
+                   "try: pthread_setspecific() failed"); \
         } while (0)
 #else /* !PTHREAD_ONCE_INIT */
     extern try_t_ *try_stack_;
@@ -320,7 +320,7 @@ struct try_s_ {
 #define TRY_TRY_ \
     do { \
         try_t_ try_this_; \
-        int try_pushed_ = 1; \
+        volatile int try_pushed_ = 1; \
         try_this_.ball.code = 0; \
         try_this_.ball.free = 0; \
         try_this_.ball.why = NULL; \
